import { Text, View } from "@tarojs/components";
import { memo, useState } from "react";
import AmountShow from "../amountShow";
import classnames from "classnames";
import styles  from './index.module.scss'

import MCheckbox from "@/components/checkbox";
import Popup from "@/components/popup";
import OfflinePay from "../offlinePay";
import ScanPay from "../scanPay";

type Param = {
    show?: true|false,
    onClose?: () => void
}
export default memo(({show = false, onClose}:Param) => {

    //线下付款
    const [offlinePayShow, setofflinePayShow] = useState(false)
    const onShowOfflinePay = () => {
        setofflinePayShow(true)
        onClose?.()
    }

    //扫码支付
    const [scanPayShow, setScanPayShow] = useState(false)
    const onShowScanPay = () => {
        setScanPayShow(true)
        onClose?.()
    }
    return (
        <View className={styles.payment_main}>
            <Popup show={show} showTitle={false} onClose={onClose} >
                <View className={styles.payment_con}>
                    <View className={classnames('iconfont icon-a-moreback', styles.miconfont_title)} onClick={onClose}></View>
                    <View className={styles.title}>订单支付</View>
                    <View className={styles.amount}>
                        <AmountShow status={2} number={6000.33}/>
                    </View>
                    <View className={styles.payment_list}>
                        <View className={styles.payment_list_top_border}></View>
                        <View className={styles.payment_list_title}>
                            {/* <Text>向商家发起支付</Text> */}
                            <View className={styles.payment_list_title_price}>
                                <View className={styles.payment_list_title_price_item}>
                                    <Text>订单金额</Text>
                                    <Text>¥6,001.00</Text>
                                </View>
                                <View className={styles.payment_list_title_price_item}>
                                    <Text>已付金额</Text>
                                    <Text>¥1,801.00</Text>
                                </View>
                            </View>
                        </View>
                        <View className={styles.payment_list_con}>
                            <View className={styles.payment_list_item}>
                                <View className={styles.payment_list_item_left}>
                                    <View className={styles.payment_list_item_left_name}>
                                        <View className={classnames('iconfont icon-a-tuikuanshouhou', styles.miconfont)}></View>
                                        <View className={styles.payment_list_item_left_text}>预存款</View>
                                    </View>
                                    <View className={styles.payment_list_item_left_price}>金额不足，剩余 ¥0.00</View>
                                </View>
                                <MCheckbox  status={true} onSelect={() => console.log()} onClose={() =>console.log()}/>
                            </View>
                            <View className={styles.payment_list_item}>
                                <View className={styles.payment_list_item_left}>
                                    <View className={styles.payment_list_item_left_name}>
                                        <View className={classnames('iconfont icon-a-tuikuanshouhou', styles.miconfont)}></View>
                                        <View className={styles.payment_list_item_left_text}>x天账期</View>
                                    </View>
                                    <View className={styles.payment_list_item_left_price}>可用额度 ¥3,000.00</View>
                                </View>
                                <MCheckbox  status={true} onSelect={() => console.log()} onClose={() =>console.log()}/>
                            </View>
                            <View className={styles.payment_list_item} onClick={onShowOfflinePay}>
                                <View className={styles.payment_list_item_left}>
                                    <View className={styles.payment_list_item_left_name}>
                                        <View className={classnames('iconfont icon-a-tuikuanshouhou', styles.miconfont)}></View>
                                        <View className={styles.payment_list_item_left_text}>线下汇款</View>
                                    </View>
                                </View>
                                <View className={classnames('iconfont icon-a-moreback', styles.miconfont_more)}></View>
                            </View>
                            <View className={styles.payment_list_item} onClick={onShowScanPay}>
                                <View className={styles.payment_list_item_left}>
                                    <View className={styles.payment_list_item_left_name}>
                                        <View className={classnames('iconfont icon-a-tuikuanshouhou', styles.miconfont)}></View>
                                        <View className={styles.payment_list_item_left_text}>扫码支付</View>
                                    </View>
                                </View>
                                <View className={classnames('iconfont icon-a-moreback', styles.miconfont_more)}></View>
                            </View>
                        </View>
                    </View>
                    <View className={styles.btns}>确认交易</View>
                </View>
            </Popup>
            <OfflinePay show={offlinePayShow} onClose={() => setofflinePayShow(false)}/>
            <ScanPay show={scanPayShow} onClose={() => setScanPayShow(false)}/>
        </View>
        
    )
})