import { formatHashTag, formatImgUrl, formatPriceDiv } from "@/common/fotmat";
import { useSelector } from "@/reducers/hooks";
import { Image, Text, View } from "@tarojs/components"
import classnames from "classnames";
import { memo, useCallback } from "react";
import styles  from './index.module.scss'

type Param = {
    value?: {
        order_no: string,
        sale_mode: number,
        sale_mode_name: string,
        status_name: string,
        shipment_mode_name: string,
        product_list: any[],
        total_fabrics: number,
        total_colors: number,
        total_number: number
    }
}
export default memo(({value}: Param) => {
    const userInfo = useSelector(state => state.userInfo)
    //对应数量
    const formatCount = useCallback((item, sale_mode) => {
        return sale_mode == 0? item.roll : Number(item.length / 100)
    }, [value])
    //对应单价
    const standardPrice = useCallback((price, sale_mode) => {
        return formatPriceDiv(price).toLocaleString() + '/' + (sale_mode == 1?'m':'kg')
    }, [value])
    return (
        <View className={styles.order_item}>
            <View className={styles.header}>
                <View className={styles.user}>
                <Image src={`${userInfo.adminUserInfo.avatar_url}`}/>
                <Text className={styles.name}>{userInfo.adminUserInfo.user_name}</Text>
                </View>
                <View className={styles.order_num}>
                <Text>订单号：{value?.order_no}</Text>
                <Text className={classnames(styles.miconfont, 'iconfont, icon-a-moreback')}></Text>
                </View>
                <View className={styles.tag}>{value?.shipment_mode_name}</View>
            </View>
            <View className={styles.product_con}>
                <View className={styles.product_title}>
                    <View className={styles.product_tag}>{value?.sale_mode_name}</View>
                    <View className={styles.product_name}>{formatHashTag(value?.product_list[0].code, value?.product_list[0].name)}</View>
                    <View className={styles.product_status}>{value?.status_name}</View>
                </View>
                <View className={styles.product_list}>
                    <View className={styles.image}>
                    <Image src={formatImgUrl(value?.product_list[0].product_colors[0].texture_url)}/>
                    <View className={styles.color_num}>{value?.product_list[0].product_colors[0].code}</View>
                    </View>
                    <View className={styles.color_list}>
                        {value?.product_list[0].product_colors.map((itemColor, index) => {
                                return (
                                    (index <= 1)&&<View className={styles.color_item}>
                                        <View className={styles.color_title}>{formatHashTag(itemColor.code, itemColor.name)}</View>
                                        <View className={styles.color_price}>{standardPrice(itemColor.sale_price, value.sale_mode)}</View>
                                        <View className={styles.color_num}>×{formatCount(itemColor, value.sale_mode)}条</View>
                                    </View>
                                )
                            
                            })
                        }
                        <View className={styles.color_item}>
                            <View className={styles.color_more}>……</View>
                            <View className={styles.color_more}>……</View>
                            <View className={styles.color_more}>……</View>
                        </View>
                    </View>
                </View>
                <View className={styles.color_count_num}>{`${value?.total_fabrics}种面料，${value?.total_colors}种颜色，共${value?.total_number}条`}</View>
            </View>
            <View className={styles.btns_list}>
                <View className={styles.btns_item}>取消订单</View>
                <View className={styles.btns_item}>修改地址</View>
                <View className={styles.btns_item}>修改地址</View>
                <View className={classnames(styles.btns_item, styles.end_btn)}>去付款</View>
            </View>
        </View>
    )
})